@@ -16,11 +16,11 @@ Toader::Entry - This holds a blog/article/whatever entry.
 
 =head1 VERSION
 
-Version 0.1.0
+Version 1.0.0
 
 =cut
 
-our $VERSION = '0.1.0';
+our $VERSION = '1.0.0';
 
 =head1 SYNOPSIS
 
@@ -35,6 +35,8 @@ If any of the new methods error, the error is permanent.
 
 This creates the a object that represents a entry.
 
+One argument is taken and it s a hash reference.
+
 =head3 args hash
 
 =head4 renderer
@@ -73,7 +75,11 @@ This is a L<Text::Tags> parsable string for the tags.
 
 This is a list of files that will be made available with this entry.
 
-    my $foo = Toader::isaToaderDir->new(\%args);
+=head4 toader
+
+This is a L<Toader> object.
+
+    my $foo = Toader::Entry->new(\%args);
     if ($foo->error){
         warn('Error:'.$foo->error.': '.$foo->errorString);
     }
@@ -92,6 +98,36 @@ sub new{
 			  perror=>undef,
 			  dir=>undef,
 			  entryName=>undef,
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noNameSpecified',
+					  2=>'emailMIMEerror',
+					  3=>'notAnArray',
+					  4=>'fileDoesNotExist',
+					  5=>'MIMEinfoError',
+					  6=>'unableToOpenFile',
+					  7=>'emailMIMEerror',
+					  8=>'noBody',
+					  9=>'invalidEntryName',
+					  10=>'notAtoaderDir',
+					  11=>'noDirSpecified',
+					  12=>'noDirSet',
+					  13=>'noLongerAtoaderDir',
+					  14=>'noEntryDir',
+					  15=>'noSummarySpecified',
+					  16=>'noEntryNameSet',
+					  17=>'dirDNEorNAD',
+					  18=>'noFileSpecified',
+					  19=>'publishValError',
+					  20=>'getVCSerrored',
+					  21=>'VCSusableErrored',
+					  22=>'underVCSerrored',
+					  23=>'VCSaddErrored',
+					  24=>'notAtoaderObj',
+					  25=>'noToaderObj',
+				  },
+			  },
+			  VCSusable=>0,
 			  };
 	bless $self;
 
@@ -248,6 +284,45 @@ sub new{
 
 	$self->{mime}=$mime;
 
+	#if we have a Toader object, reel it in
+	if ( ! defined( $args{toader} ) ){
+		$self->{perror}=1;
+		$self->{error}=25;
+		$self->{errorString}='No Toader object specified';
+		$self->warn;
+		return $self;
+	}
+	if ( ref( $args{toader} ) ne "Toader" ){
+		$self->{perror}=1;
+		$self->{error}=24;
+		$self->{errorString}='The object specified is a "'.ref($args{toader}).'"';
+		$self->warn;
+		return $self;
+	}
+	$self->{toader}=$args{toader};
+
+	#gets the Toader::VCS object
+	$self->{vcs}=$self->{toader}->getVCS;
+	if ( $self->{toader}->error ){
+		$self->{perror}=1;
+		$self->{error}=20;
+		$self->{errorString}='Toader->getVCS errored. error="'.
+			$self->{toader}->error.'" errorString="'.$self->{toader}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+	
+	#checks if VCS is usable
+	$self->{VCSusable}=$self->{vcs}->usable;
+	if ( $self->{vcs}->error ){
+		$self->{perror}=1;
+		$self->{error}=21;
+		$self->{errorString}='Toader::VCS->usable errored. error="'.
+			$self->{toader}->error.'" errorString="'.$self->{toader}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+
 	return $self;
 }
 
@@ -255,9 +330,10 @@ sub new{
 
 This creates a new entry from a string.
 
-One argument is accepted and it is the name string to use.
+Two argument are accepted. The first is the entry string and the second
+is a L<Toader> object. 
 
-    my $foo=Toader::Entry->newFromString($entryString);
+    my $foo=Toader::Entry->newFromString($entryString, $toader);
     if($foo->error){
         warn('Error:'.$foo->error.': '.$foo->errorString);
     }
@@ -266,6 +342,7 @@ One argument is accepted and it is the name string to use.
 
 sub newFromString{
 	my $string=$_[1];
+	my $toader=$_[2];
 
 	my $self={
 			  error=>undef,
@@ -274,6 +351,37 @@ sub newFromString{
 			  perror=>undef,
 			  dir=>undef,
 			  entryName=>undef,
+			  toader=>undef,
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noNameSpecified',
+					  2=>'emailMIMEerror',
+					  3=>'notAnArray',
+					  4=>'fileDoesNotExist',
+					  5=>'MIMEinfoError',
+					  6=>'unableToOpenFile',
+					  7=>'emailMIMEerror',
+					  8=>'noBody',
+					  9=>'invalidEntryName',
+					  10=>'notAtoaderDir',
+					  11=>'noDirSpecified',
+					  12=>'noDirSet',
+					  13=>'noLongerAtoaderDir',
+					  14=>'noEntryDir',
+					  15=>'noSummarySpecified',
+					  16=>'noEntryNameSet',
+					  17=>'dirDNEorNAD',
+					  18=>'noFileSpecified',
+					  19=>'publishValError',
+					  20=>'getVCSfailed',
+					  21=>'VCSusableFailed',
+					  22=>'underVCSerrored',
+					  23=>'VCSaddErrored',
+					  24=>'notAtoaderObj',
+					  25=>'noToaderObj',
+				  },
+			  },
+			  VCSusable=>0,
 			  };
 	bless $self;
 
@@ -352,6 +460,45 @@ sub newFromString{
 	
 	$self->{mime}=$mime;
 
+	#if we have a Toader object, reel it in
+	if ( ! defined( $toader ) ){
+		$self->{perror}=1;
+		$self->{error}=25;
+		$self->{errorString}='No Toader object specified';
+		$self->warn;
+		return $self;
+	}
+	if ( ref( $toader ) ne "Toader" ){
+		$self->{perror}=1;
+		$self->{error}=24;
+		$self->{errorString}='The object specified is a "'.ref($toader).'"';
+		$self->warn;
+		return $self;
+	}
+	$self->{toader}=$toader;
+
+	#gets the Toader::VCS object
+	$self->{vcs}=$self->{toader}->getVCS;
+	if ( $toader->error ){
+		$self->{perror}=1;
+		$self->{error}=20;
+		$self->{errorString}='Toader->getVCS errored. error="'.
+			$self->{toader}->error.'" errorString="'.$self->{toader}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+	
+	#checks if VCS is usable
+	$self->{VCSusable}=$self->{vcs}->usable;
+	if ( $self->{vcs}->error ){
+		$self->{perror}=1;
+		$self->{error}=21;
+		$self->{errorString}='Toader::VCS->usable errored. error="'.
+			$self->{toader}->error.'" errorString="'.$self->{toader}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+
 	return $self;
 }
 
@@ -582,14 +729,8 @@ sub entryNameSet{
 		return undef;
 	}
 
-	#generate a entry name if one has not been
-	if (!defined($entryName)) {
-		my $ehelper=Toader::Entry::Helper->new;
-		$entryName=$ehelper->generateEntryName;
-	}
-
 	#makes sure the entry name is valid
-	my $ehelper=Toader::Entry::Helper->new;
+	my $ehelper=Toader::Entry::Helper->new( $self->{toader} ) ;
 	my $returned=$ehelper->validEntryName($entryName);
 	if ( ! $returned ) {
 		$self->{error}=9;
@@ -598,6 +739,11 @@ sub entryNameSet{
 		return undef;
 	}
 
+	#generate a entry name if one has not been
+	if (!defined($entryName)) {
+		$entryName=$ehelper->generateEntryName;
+	}
+
 	$self->{entryName}=$entryName;
 
 	return 1;
@@ -1348,6 +1494,34 @@ sub write{
 	print $fh $entry;
 	close($fh);
 
+	#if VCS is not usable, stop here
+	if ( ! $self->{VCSusable} ){
+		return 1;
+	}
+
+	#if it is under VCS, we have nothing to do
+	my $underVCS=$self->{vcs}->underVCS($file);
+	if ( $self->{vcs}->error ){
+		$self->{error}=22;
+		$self->{errorString}='Toader::VCS->underVCS errored. error="'.
+			$self->{vcs}->error.'" errorString="'.$self->{vcs}->errorString.'"';
+		$self->warn;
+		return undef;
+	}
+	if ( $underVCS ){
+		return 1;
+	}
+
+	#add it as if we reach here it is not under VCS and VCS is being used
+	$self->{vcs}->add( $file );
+	if ( $self->{vcs}->error ){
+		$self->{error}=23;
+		$self->{errorString}='Toader::VCS->add errored. error="'.
+			$self->{vcs}->error.'" errorString="'.$self->{vcs}->errorString.'"';
+		$self->warn;
+		return undef;
+	}
+
 	return 1;
 }
 
@@ -1462,84 +1636,108 @@ sub toDir{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noNameSpecified
 
 No name specified.
 
-=head2 2
+=head2 2, emailMIMEerror
 
 Unable to create L<Email::MIME> object.
 
-=head2 3
+=head2 3, notAnArray
 
 Has files specified, but the passed object is not a array.
 
-=head2 4
+=head2 4, fileDoesNotExist
 
 The file does not exist or is not a file.
 
-=head2 5
+=head2 5, MIMEinfoError
 
 File::MimeInfo->mimetype returned undef, meaning the file does not exist or is not readable.
 
-=head2 6
+=head2 6, unableToOpenFile
 
 Unable to open the file.
 
-=head2 7
+=head2 7, emailMIMEerror
 
 Unable to create a L<Email::MIME> object for one of the parts/files.
 
-=head2 8
+=head2 8, noBody
 
 No body defined.
 
-=head2 9
+=head2 9, invalidEntryName
 
 Not a valid entry name.
 
-=head2 10
+=head2 10. notAtoaderDir
 
 The specified directory is not a Toader directory.
 
-=head2 11
+=head2 11, noDirSpecified
 
 No directory specified.
 
-=head2 12
+=head2 12, noDirSet
 
 No directory has been set yet.
 
-=head2 13
+=head2 13, noLongerAtoaderDir
 
 The directory is no longer a L<Toader> directory. It looks like
 it has been removed.
 
-=head2 14
+=head2 14, noEntryDir
 
 The entries directory did not exist and was not able to create it.
 
-=head2 15
+=head2 15, noSummarySpecified
 
 No summary specified.
 
-=head2 16
+=head2 16, noEntryNameSet
 
 No entry name has been set.
 
-=head2 17
+=head2 17, dirDNEorNAD
 
 The directory does not exist or is a not a directory.
 
-=head2 18
+=head2 18, noFileSpecified
 
 No file specified.
 
-=head2 19
+=head2 19, publishValError
 
 Invalid publish value. It is not a recognized boolean value of
 either "0" or "1".
 
+=head2 20, getVCSerrored
+
+L<Toader>->getVCS errored.
+
+=head2 21, VCSusableErrored
+
+L<Toader::VCS>->usable errored.
+
+=head2 22, underVCSerrored
+
+L<Toader::VCS>->underVCS errored.
+
+=head2 23, VCSaddErrored
+
+L<Toader::VCS>->add errored.
+
+=head2 24, notAtoaderObj
+
+The specified object is not a L<Toader> object.
+
+=head2 25, noToaderObj
+
+Nothing passed for a L<Toader> object.
+
 =head1 AUTHOR
 
 Zane C. Bowers-Hadley, C<< <vvelox at vvelox.net> >>
@@ -1586,7 +1784,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011 Zane C. Bowers-Hadley.
+Copyright 2013 Zane C. Bowers-Hadley.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
