@@ -15,11 +15,11 @@ Toader::Page - This provides methods for a named page.
 
 =head1 VERSION
 
-Version 0.0.2
+Version 1.0.0
 
 =cut
 
-our $VERSION = '0.0.2';
+our $VERSION = '1.0.0';
 
 =head1 SYNOPSIS
 
@@ -34,6 +34,9 @@ If any of the new methods error, the error is permanent.
 
 This creates the a object that represents a page.
 
+Two arguments are taken. The first is a hash reference that
+is documented below.
+
 =head3 args hash
 
 =head4 renderer
@@ -65,6 +68,10 @@ and "1".
 
 If not specified, it uses "1".
 
+=head4 toader
+
+This is a L<Toader> object.
+
     my $foo = Toader::isaToaderDir->new(\%args);
     if ($foo->error){
        warn('Error:'.$foo->error.': '.$foo->errorString);
@@ -83,6 +90,30 @@ sub new{
 			  errorString=>'',
 			  perror=>undef,
 			  dir=>undef,
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noPageName',
+					  2=>'emailMIMEcreationFailed',
+					  3=>'notAnArray',
+					  4=>'fileDoesNotExist',
+					  5=>'MIMEinfoError',
+					  6=>'unableToOpenFile',
+					  7=>'emailMIMEerror',
+					  8=>'noBody',
+					  9=>'notAtoaderDir',
+					  10=>'noLongAtoaderDir',
+					  11=>'nodirSet',
+					  12=>'pagesDirCreationFailed',
+					  13=>'publishValError',
+					  14=>'notAtoaderObj',
+					  15=>'getVCSerrored',
+					  16=>'VCSusableErrored',
+					  17=>'underVCSerror',
+					  18=>'VCSaddError',
+					  19=>'noToaderObj',
+				  },
+			  },
+			  VCSusable=>0,
 			  };
 	bless $self;
 
@@ -224,6 +255,45 @@ sub new{
 
 	$self->{mime}=$mime;
 
+	#if we have a Toader object, reel it in
+	if ( ! defined( $args{toader} ) ){
+		$self->{perror}=1;
+		$self->{error}=19;
+		$self->{errorString}='No $args{toader} specified';
+		$self->warn;
+		return $self;
+	}
+	if ( ref( $args{toader} ) ne "Toader" ){
+		$self->{perror}=1;
+		$self->{error}=14;
+		$self->{errorString}='The object specified is a "'.ref($args{toader}).'"';
+		$self->warn;
+		return $self;
+	}
+	$self->{toader}=$args{toader};
+
+	#gets the Toader::VCS object
+	$self->{vcs}=$self->{toader}->getVCS;
+	if ( $self->{toader}->error ){
+		$self->{perror}=1;
+		$self->{error}=15;
+		$self->{errorString}='Toader->getVCS errored. error="'.
+			$self->{toader}->error.'" errorString="'.$self->{toader}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+	
+	#checks if VCS is usable
+	$self->{VCSusable}=$self->{vcs}->usable;
+	if ( $self->{vcs}->error ){
+		$self->{perror}=1;
+		$self->{error}=16;
+		$self->{errorString}='Toader::VCS->usable errored. error="'.
+			$self->{toader}->error.'" errorString="'.$self->{toader}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+
 	return $self;
 }
 
@@ -231,9 +301,11 @@ sub new{
 
 This creates a new page from a string.
 
-One argument is accepted and it is the name string to use.
+There are two required arguments, the first being a string
+containing the page in question and the second being
+L<Toader> object.
 
-    my $foo=Toader::Page->newFromString($pageString);
+    my $foo=Toader::Page->newFromString($pageString, $toader);
     if($foo->error){
         warn('Error:'.$foo->error.': '.$foo->errorString);
     }
@@ -242,6 +314,7 @@ One argument is accepted and it is the name string to use.
 
 sub newFromString{
 	my $string=$_[1];
+	my $toader=$_[2];
 
 	my $self={
 			  error=>undef,
@@ -249,6 +322,30 @@ sub newFromString{
 			  module=>'Toader-Page',
 			  perror=>undef,
 			  dir=>undef,
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noPageName',
+					  2=>'emailMIMEcreationFailed',
+					  3=>'notAnArray',
+					  4=>'fileDoesNotExist',
+					  5=>'MIMEinfoError',
+					  6=>'unableToOpenFile',
+					  7=>'emailMIMEerror',
+					  8=>'noBody',
+					  9=>'notAtoaderDir',
+					  10=>'noLongAtoaderDir',
+					  11=>'nodirSet',
+					  12=>'pagesDirCreationFailed',
+					  13=>'publishValError',
+					  14=>'notAtoaderObj',
+					  15=>'getVCSfailed',
+					  16=>'VCSusableFailed',
+					  17=>'underVCSerror',
+					  18=>'VCSaddError',
+					  19=>'noToaderObj',
+				  },
+			  },
+			  VCSusable=>0,
 			  };
 	bless $self;
 
@@ -316,6 +413,45 @@ sub newFromString{
 	
 	$self->{mime}=$mime;
 
+	#if we have a Toader object, reel it in
+	if ( ! defined( $toader ) ){
+		$self->{perror}=1;
+		$self->{error}=19;
+		$self->{errorString}='No Toader object specified';
+		$self->warn;
+		return $self;
+	}
+	if ( ref( $toader ) ne "Toader" ){
+		$self->{perror}=1;
+		$self->{error}=14;
+		$self->{errorString}='The object specified is a "'.ref($toader).'"';
+		$self->warn;
+		return $self;
+	}
+	$self->{toader}=$toader;
+
+	#gets the Toader::VCS object
+	$self->{vcs}=$self->{toader}->getVCS;
+	if ( $toader->error ){
+		$self->{perror}=1;
+		$self->{error}=15;
+		$self->{errorString}='Toader->getVCS errored. error="'.
+			$self->{toader}->error.'" errorString="'.$self->{toader}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+	
+	#checks if VCS is usable
+	$self->{VCSusable}=$self->{vcs}->usable;
+	if ( $self->{vcs}->error ){
+		$self->{perror}=1;
+		$self->{error}=16;
+		$self->{errorString}='Toader::VCS->usable errored. error="'.
+			$self->{toader}->error.'" errorString="'.$self->{toader}->errorString.'"';
+		$self->warn;
+		return $self;
+	}
+
 	return $self;
 }
 
@@ -1112,7 +1248,35 @@ sub write{
 	}
 	print $fh $pageString;
 	close($fh);
-	
+
+	#if VCS is not usable, stop here
+	if ( ! $self->{VCSusable} ){
+		return 1;
+	}
+
+	#if it is under VCS, we have nothing to do
+	my $underVCS=$self->{vcs}->underVCS($file);
+	if ( $self->{vcs}->error ){
+		$self->{error}=17;
+		$self->{errorString}='Toader::VCS->underVCS errored. error="'.
+			$self->{vcs}->error.'" errorString="'.$self->{vcs}->errorString.'"';
+		$self->warn;
+		return undef;
+	}
+	if ( $underVCS ){
+		return 1;
+	}
+
+	#add it as if we reach here it is not under VCS and VCS is being used
+	$self->{vcs}->add( $file );
+	if ( $self->{vcs}->error ){
+		$self->{error}=18;
+		$self->{errorString}='Toader::VCS->add errored. error="'.
+			$self->{vcs}->error.'" errorString="'.$self->{vcs}->errorString.'"';
+		$self->warn;
+		return undef;
+	}	
+
 	return 1;
 }
 
@@ -1224,61 +1388,86 @@ sub toDir{
     return $self->renderDir.'/'.$self->{entryName};
 }
 
+=head1 ERROR CODES/FLAGS
 
-=head1 ERROR CODES
-
-=head2 1
+=head2 1, noPageName
 
 No name specified.
 
-=head2 2
+=head2 2, emailMIMEcreationFailed
 
 Unable to create L<Email::MIME> object.
 
-=head2 3
+=head2 3, notAnArray
 
 Has files specified, but the passed object is not a array.
 
-=head2 4
+=head2 4, fileDoesNotExist
 
 The file does not exist or is not a file.
 
-=head2 5
+=head2 5, MIMEinfoError
 
 File::MimeInfo->mimetype returned undef, meaning the file does not exist or is not readable.
 
-=head2 6
+=head2 6, unableToOpenFile
 
 Unable to open the file.
 
-=head2 7
+=head2 7, emailMIMEerror
 
 Unable to create a L<Email::MIME> object for one of the parts/files.
 
-=head2 8
+=head2 8, noBody
 
 No body defined.
 
-=head2 9
+=head2 9, notAtoaderDir
 
 Not a L<Toader> directory.
 
-=head2 10
+=head2 10, noLonderAtoaderDir
 
 No longer appears to be a L<Toader> directory.
 
-=head2 11
+=head2 11, noDirSet
 
 No directory has been specified.
 
-=head2 12
+=head2 12, pagesDirCreationFailed
 
 The pages directory could not be created.
 
-=head2 13
+=head2 13, publishValError
 
 The publish value is not a recognized boolean value.
 
+Only '0' and '1' is recognized.
+
+=head2 14, notAtoaderObj
+
+The specified object is not a L<Toader> object.
+
+=head2 15, getVCSerrored
+
+L<Toader>->getVCS errored.
+
+=head2 16, VCSusableErrored
+
+L<Toader::VCS>->usable errored.
+
+=head2 17, underVCSerror
+
+L<Toader::VCS>->underVCS errored.
+
+=head2 18, VCSaddErrored
+
+L<Toader::VCS>->add errored.
+
+=head2 19, noToaderObj
+
+No L<Toader> object specified.
+
 =head1 AUTHOR
 
 Zane C. Bowers-Hadley, C<< <vvelox at vvelox.net> >>
