@@ -19,11 +19,11 @@ Toader::Render::AutoDoc - This renders a Toader::AutoDoc object.
 
 =head1 VERSION
 
-Version 0.1.0
+Version 0.2.1
 
 =cut
 
-our $VERSION = '0.1.0';
+our $VERSION = '0.2.1';
 
 =head1 SYNOPSIS
 
@@ -67,6 +67,25 @@ sub new{
 			  errorString=>'',
 			  perror=>undef,
 			  toDir=>'../',
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noObj',
+					  2=>'noToaderObj',
+					  3=>'objPerror',
+					  4=>'toaderObjPerror',
+					  5=>'noDirSet',
+					  6=>'cleanupNewErrored',
+					  7=>'cleanupErrored',
+					  8=>'fileListFailed',
+					  9=>'pathhelperNewErrored',
+					  11=>'noOutputDirSet',
+					  12=>'outputDirDoesNotExist',
+					  13=>'outputPageDirCreationFailed',
+					  14=>'outputFileDirCreationFailed',
+					  15=>'makePathFailed',
+					  16=>'copyFailed',
+				  },
+			  },
 			  };
 	bless $self;
 
@@ -136,9 +155,13 @@ sub new{
 		$self->warn;
 		return $self;
 	}
+	$self->{dir}=$self->{obj}->dirGet;
 
 	#initialize this here for simplicity
-	$self->{t}=Toader::Templates->new({ dir=>$self->{obj}->dirGet });
+	$self->{t}=Toader::Templates->new({
+		dir=>$self->{obj}->dirGet,
+		toader=>$args{toader},
+									  });
 
 	#initialize the general object here for simplicity
 	$self->{g}=Toader::Render::General->new(
@@ -153,16 +176,6 @@ sub new{
 		$self->{perror}='';
 	}
 
-	#make sure the renderable object has a directory set
-	$self->{dir}=$self->{obj}->dirGet;
-	if ( ! defined( $self->{dir} ) ){
-		$self->{perror}=1;
-		$self->{error}=10;
-		$self->{errorString}='The renderable object does not have a directory specified';
-		$self->warn;
-		return $self;
-	}
-
 	#initialize the Toader::pathHelper
 	$self->{ph}=Toader::pathHelper->new( $self->{dir} );
 	if ( $self->{ph}->error ){
@@ -420,69 +433,65 @@ sub render{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noObj
 
 No L<Toader::AutoDoc> object specified.
 
-=head2 2
+=head2 2, noToaderObj
 
 No L<Toader> object specified.
 
-=head2 3
+=head2 3, objPerror
 
 The L<Toader::AutoDoc> object has a permanent error set.
 
-=head2 4
+=head2 4, toaderObjPerror
 
 The L<Toader> object has a permanent error set.
 
-=head2 5
+=head2 5, noDirSet
 
 The L<Toader::AutoDoc> object does not have a directory set
 
-=head2 6
+=head2 6, cleanupNewErrored
 
 Failed to initialize the cleanup module.
 
-=head2 7
+=head2 7, cleanupErrored
 
 Failed to cleanup.
 
-=head2 8
+=head2 8, fileListFailed
 
 Failed to get a list of files.
 
-=head2 9
+=head2 9, pathhelperNewErrored
 
 Failed to initialize the path helper.
 
-=head2 10
-
-The object does not have a directory set.
-
-=head2 11
+=head2 11, noOutputDirSet
 
 The L<Toader> object does not have a output directory set.
 
-=head2 12
+=head2 12, outputDirDoesNotExist
 
 The output directory does not exist.
 
-=head2 13
+=head2 13, outputPageDirCreationFailed
 
 The output page directory could not be created.
 
-=head2 14
+=head2 14, outputFileDirCreationFailed
 
 The output file directory could not be created.
 
-=head2 15
+=head2 15, makePathFailed
 
 make_path failed.
 
-=head2 16
+=head2 16, copyFailed
 
-Failed to copy it.
+Failed to copy the HTML produced from the POD to where it belongs.
 
 =head1 AUTHOR
 
@@ -531,7 +540,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012. Zane C. Bowers-Hadley.
+Copyright 2013. Zane C. Bowers-Hadley.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
