@@ -15,11 +15,11 @@ Toader::Render::Directory - Renders a Toader::Directory object.
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.1.1
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.1';
 
 =head1 SYNOPSIS
 
@@ -63,6 +63,17 @@ sub new{
 			  errorString=>'',
 			  perror=>undef,
 			  toDir=>'./',
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noObj',
+					  2=>'noToaderObj',
+					  3=>'objPerror',
+					  4=>'toaderObjPerror',
+					  5=>'noDirSet',
+					  6=>'cleanupErrored',
+					  7=>'generalInitErrored',
+				  },
+			  },
 			  };
 	bless $self;
 
@@ -125,7 +136,10 @@ sub new{
     }
 
 	#initialize this here for simplicity
-	$self->{t}=Toader::Templates->new({ dir=>$self->{obj}->dirGet });
+	$self->{t}=Toader::Templates->new({ 
+		dir=>$self->{obj}->dirGet,
+		toader=>$args{toader},
+									  });
 
     #make sure a directory is set
     if( ! defined( $self->{obj}->dirGet ) ){
@@ -135,16 +149,7 @@ sub new{
         $self->warn;
         return $self;
     }
-
-	#make sure the renderable object has a directory set
 	$self->{dir}=$self->{obj}->dirGet;
-	if ( ! defined( $self->{dir} ) ){
-		$self->{perror}=1;
-		$self->{error}=10;
-		$self->{errorString}='The renderable object does not have a directory specified';
-		$self->warn;
-		return $self;
-	}
 
 	#initialize the Toader::pathHelper
 	$self->{ph}=Toader::pathHelper->new( $self->{dir} );
@@ -434,31 +439,31 @@ sub render{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noObj
 
 No L<Toader::Directory> object specified.
 
-=head2 2
+=head2 2, noToaderObj
 
 No L<Toader> object specified.
 
-=head2 3
+=head2 3, objPerror
 
 The L<Toader::Directory> object has a permanent error set.
 
-=head2 4
+=head2 4, toaderObjPerror
 
 The L<Toader> object has a permanent error set.
 
-=head2 5
+=head2 5, noDirSet
 
-The Toader::Directory object does not have a directory set.
+The L<Toader::Directory> object does not have a directory set.
 
-=head2 6
+=head2 6, cleanupErrored
 
 Initializing L<Toader::Render::Directory::Cleanup> failed.
 
-=head2 7
+=head2 7, generalInitErrored
 
 Failed to initialize L<Toader::Render::General>.
 
@@ -507,7 +512,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011. Zane C. Bowers-Hadley.
+Copyright 2013. Zane C. Bowers-Hadley.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
