@@ -18,11 +18,11 @@ Toader::Render::Gallery - This renders a Toader::Gallery object.
 
 =head1 VERSION
 
-Version 0.0.0
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.0';
+our $VERSION = '0.1.0';
 
 =head1 SYNOPSIS
 
@@ -60,6 +60,29 @@ sub new{
 			  errorString=>'',
 			  perror=>undef,
 			  toDir=>'../',
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noObj',
+					  2=>'noToaderObj',
+					  3=>'objPerror',
+					  4=>'toaderPerror',
+					  5=>'noDirSet',
+					  6=>'pathhelperInitErroered',
+					  7=>'realative2rootErrored',
+					  9=>'notUnderSrcPath',
+					  10=>'dirStartsWithPeriod',
+					  11=>'srcPathDoesNotExist',
+					  12=>'outputDirDoesNotExist',
+					  13=>'srcDirOpenFailed',
+					  14=>'smallThumbFileOpenFailed',
+					  15=>'smallThumbPathCreationFailed',
+					  16=>'largeThumbPathCreationFailed',
+					  17=>'generalInitErrored',
+					  18=>'renderTemplateErrored',
+					  19=>'pathCreationFailed',
+					  20=>'pathCleanupFailed',
+				  },
+			  },
 			  };
 	bless $self;
 
@@ -129,9 +152,10 @@ sub new{
 		$self->warn;
 		return $self;
 	}
+	$self->{dir}=$self->{obj}->dirGet;
 
 	#initialize this here for simplicity
-	$self->{t}=Toader::Templates->new({ dir=>$self->{obj}->dirGet });
+	$self->{t}=Toader::Templates->new({ dir=>$self->{obj}->dirGet, toader=>$self->{toader} });
 
 	#initialize the general object here for simplicity
 	$self->{g}=Toader::Render::General->new(
@@ -151,16 +175,6 @@ sub new{
 		return undef;
 	}
 
-	#make sure the renderable object has a directory set
-	$self->{dir}=$self->{obj}->dirGet;
-	if ( ! defined( $self->{dir} ) ){
-		$self->{perror}=1;
-		$self->{error}=8;
-		$self->{errorString}='The renderable object does not have a directory specified';
-		$self->warn;
-		return $self;
-	}
-
 	#initialize the Toader::pathHelper
 	$self->{ph}=Toader::pathHelper->new( $self->{dir} );
 	if ( $self->{ph}->error ){
@@ -848,83 +862,79 @@ sub updateScaled{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noObj
 
 No L<Toader::Gallery> object specified.
 
-=head2 2
+=head2 2, noToaderObj
 
 No L<Toader> object specified.
 
-=head2 3
+=head2 3, objPerror
 
 The L<Toader::Gallery> object has a permanent error set.
 
-=head2 4
+=head2 4, toaderPerror
 
 The L<Toader> object has a permanent error set.
 
-=head2 5
+=head2 5, noDirSet
 
 The L<Toader::Gallery> object does not have a directory set
 
-=head2 6
+=head2 6, pathhalperInitErrored
 
 Failed to initialize a Toader::pathHelper.
 
-=head2 7
+=head2 7, realative2rootErrored
 
 Failed to get relative to root.
 
-=head2 8
-
-The Toader object does not have a directory set.
-
-=head2 9
+=head2 9, notUnderSrcPath
 
 The specified directory does not appear to be under the source path.
 
-=head2 10
+=head2 10, dirStartsWithPeriod
 
 The specified directory contains a directory that starts with a period.
 
-=head2 11
+=head2 11, srcPathDoesNotExit
 
 The source directory does not exist.
 
-=head2 12
+=head2 12, outputDirDoesNotExist
 
 The output directory does not exist.
 
-=head2 13
+=head2 13, srcDirOpenFailed
 
 Could not open the source directory.
 
-=head2 14
+=head2 14, smallThumbFileOpenFailed
 
 Failed to open the small thumbnail file.
 
-=head2 15
+=head2 15, smallThumbPathCreationFailed
 
 Failed to create the new path for the small thumbnails.
 
-=head2 16
+=head2 16, largeThumbPathCreationFailed
 
 Failed to create the new path for the large thumbnails.
 
-=head2 17
+=head2 17, generalInitErrored
 
 Failed to initialize L<Toader::Render::General>.
 
-=head2 18
+=head2 18, renderTemplateErrored
 
 Failed to render a template.
 
-=head2 19
+=head2 19, pathCreationFailed
 
 Failed to create the new path for the index.html.
 
-=head2 20
+=head2 20, pathCleanupFailed
 
 Path cleanup failed.
 
@@ -973,7 +983,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012. Zane C. Bowers-Hadley.
+Copyright 2014. Zane C. Bowers-Hadley.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
