@@ -12,11 +12,11 @@ Toader::Render::supportedBackends - This checks if the backend is supported or n
 
 =head1 VERSION
 
-Version 0.0.0
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.0';
+our $VERSION = '0.1.0';
 
 =head1 SYNOPSIS
 
@@ -40,6 +40,12 @@ sub new{
 			  errorString=>'',
 			  perror=>undef,
 			  soc=>Toader::Render::supportedObjects->new,
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noObj',
+					  2=>'unsupportedObj',
+				  },
+			  },
 			  };
 	bless $self;
 
@@ -101,11 +107,11 @@ sub checkBE{
 
 =head1 ERROR CODES
 
-=head2 1
+=head2 1, noObj
 
 No object defined.
 
-=head2 2
+=head2 2, unsupportedObj
 
 Unsupported object type.
 
@@ -152,7 +158,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011. Zane C. Bowers-Hadley.
+Copyright 2013. Zane C. Bowers-Hadley.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
