@@ -10,11 +10,11 @@ Toader::Templates::Defaults - This provides the default templates for Toader.
 
 =head1 VERSION
 
-Version 0.2.0
+Version 0.3.0
 
 =cut
 
-our $VERSION = '0.2.0';
+our $VERSION = '0.3.0';
 
 =head1 SYNOPSIS
 
@@ -51,6 +51,12 @@ sub new{
 		error=>undef,
 		errorString=>'',
 		templates=>{},
+			  errorExtra=>{
+				  flags=>{
+					  1=>'noTemplateNameSpecified',
+					  2=>'noSuchTemplate',
+				  },
+			  },
 	};
 	bless $self;
 
@@ -185,57 +191,9 @@ tr#hashToTable{
 
 	<div>
 
-	  <div id="sidebar" >
-		[==
-		  if ( ! $g->hasEntries ){
-		    return "";
-		  }
-	      return "<h3>Entries</h3>\n".
-		  "		".$g->entriesLink." <br>\n".
-		  "		".$g->entriesArchiveLink." <br>\n";
-		==]
-		[==
-		  my $pages=$g->listPages;
-		  if ( ( ! defined( $pages ) ) || ( $pages eq "" ) ){
-		    return "";
-		  }
-		  return "		<hr><h3>".$g->pageSummaryLink."</h3>\n".$pages."\n		<hr>\n";
-		==]
-        [==
-            if( $g->hasGallery ){
-                return "<hr>\n<h3>".$g->galleryLink."</h3>";
-            }else{
-                return "";
-            }
-        ==]
-        [==
-            if( $g->hasAnyDirs ){
-                return "<hr>\n<h3>Directories</h3>";
-            }else{
-                return "";
-            }
-        ==]
-		[== 
-			if ( $g->atRoot ){
-				return "";
-			}
-			return $g->rlink("Go To The Root")."		<br>\n		".
-			       $g->upOneDirLink."		<br>\n		<br>";
-		==]
-
-		[== 
-            if ( $g->hasSubDirs ){
-                return $g->listDirs;
-            }
-            return "";
-        ==]
-       [==
-           if ( $g->hasDocs ){
-               return "<hr>".$g->adListLink;
-           }
-           return "";
-       ==]
-	  </div>
+      <div id="sidebar" >
+        [== $g->sidebar; ==]  
+      </div>
 
 	  <div id="maincontent" >
 		[== $content ==]
@@ -256,6 +214,57 @@ tr#hashToTable{
   </body>
 </html>
 
+';
+
+	$self->{templates}{'sidebar'}='[==
+  if ( ! $g->hasEntries ){
+    return "";
+  }
+  return "<h3>Entries</h3>\n".
+    "		".$g->entriesLink." <br>\n".
+    "		".$g->entriesArchiveLink." <br>\n";
+==]
+[==
+  my $pages=$g->listPages;
+  if ( ( ! defined( $pages ) ) || ( $pages eq "" ) ){
+    return "";
+  }
+  return "		<hr><h3>".$g->pageSummaryLink."</h3>\n".$pages."\n		<hr>\n";
+==]
+[==
+  if( $g->hasGallery ){
+    return "<hr>\n<h3>".$g->galleryLink."</h3>";
+  }else{
+    return "";
+  }
+==]
+[==
+  if( $g->hasAnyDirs ){
+      return "<hr>\n<h3>Directories</h3>";
+  }else{
+    return "";
+  }
+==]
+[== 
+  if ( $g->atRoot ){
+    return "";
+  }
+  return $g->rlink("Go To The Root")."		<br>\n		".
+    $g->upOneDirLink."		<br>\n		<br>";
+==]
+
+[== 
+  if ( $g->hasSubDirs ){
+    return $g->listDirs;
+  }
+  return "";
+==]
+[==
+  if ( $g->hasDocs ){
+    return "<hr>".$g->adListLink;
+  }
+  return "";
+==]
 ';
 
 	$self->{templates}{'pageGallery'}='<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
@@ -506,13 +515,13 @@ sub listTemplates{
 	return keys( $self->{templates} );
 }
 
-=head1 ERROR CODES
+=head1 ERROR CODES/FLAGS
 
-=head2 1
+=head2 1, noTemplateNameSpecified
 
 No template name specified.
 
-=head2 2
+=head2 2, noSuchTemplate
 
 No such template.
 
@@ -561,7 +570,7 @@ L<http://search.cpan.org/dist/Toader/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011 Zane C. Bowers-Hadley.
+Copyright 2013 Zane C. Bowers-Hadley.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
